@@ -12,7 +12,10 @@ from .arnoldi import *
 
 # Rational 
 from .rational import *
+from .linratfit import *
 from .vecfit import *
 from .aaa import *
 from .paaa import *
 from .skiter import *
+from .skiter_stabilized import *
+from .pole_residue import *
